@@ -33,11 +33,12 @@ class FlipperProvider(object):
     def create_flipper_dependencies(self, masterpairname, readip, writeip, hostname1, hostname2, environment):
 
         flipper_conn = self.auth(environment= environment)
+        broadcast = writeip.rpartition('.')[0] + '.255'
 
         LOG.info("Flipper connection %s" % flipper_conn)
         flipper_cursor = flipper_conn.cursor()
         
-        sql_insert = "INSERT INTO masterpair (masterpair, name, value) values ('%s', '%s', '%s')" % (masterpairname, 'broadcast', '10.25.12.255')
+        sql_insert = "INSERT INTO masterpair (masterpair, name, value) values ('%s', '%s', '%s')" % (masterpairname, 'broadcast', broadcast)
         flipper_cursor.execute(sql_insert)
         sql_insert = "INSERT INTO masterpair (masterpair, name, value) values ('%s', '%s', '%s')" % (masterpairname, 'mysql_password', 'flipit!')
         flipper_cursor.execute(sql_insert)
